summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/knewinvestmentwizard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/knewinvestmentwizard.h')
-rw-r--r--kmymoney2/dialogs/knewinvestmentwizard.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kmymoney2/dialogs/knewinvestmentwizard.h b/kmymoney2/dialogs/knewinvestmentwizard.h
index 7540521..8e3be09 100644
--- a/kmymoney2/dialogs/knewinvestmentwizard.h
+++ b/kmymoney2/dialogs/knewinvestmentwizard.h
@@ -39,45 +39,46 @@
class KNewInvestmentWizard : public KNewInvestmentWizardDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Use this constructor for the creation of a new investment
*/
- KNewInvestmentWizard( QWidget *parent = 0, const char *name = 0 );
+ KNewInvestmentWizard( TQWidget *tqparent = 0, const char *name = 0 );
/**
* Use this constructor for the modification of an existing investment
*/
- KNewInvestmentWizard( const MyMoneyAccount& acc, QWidget *parent = 0, const char *name = 0 );
+ KNewInvestmentWizard( const MyMoneyAccount& acc, TQWidget *tqparent = 0, const char *name = 0 );
/**
* Use this constructor for the modification of an existing security
*/
- KNewInvestmentWizard( const MyMoneySecurity& sec, QWidget *parent = 0, const char *name = 0 );
+ KNewInvestmentWizard( const MyMoneySecurity& sec, TQWidget *tqparent = 0, const char *name = 0 );
~KNewInvestmentWizard();
/**
* This method sets the name in the name widget.
*/
- void setName(const QString& name);
+ void setName(const TQString& name);
/**
* Depending on the constructor used, this method either
* creates all necessary objects for the investment or updates
* them.
*
* @param parentId id of parent account for the investment
*/
- void createObjects(const QString& parentId);
+ void createObjects(const TQString& tqparentId);
const MyMoneyAccount& account(void) const { return m_account; }
protected slots:
void next(void);
void slotCheckPage(void);
- void slotCheckPage(const QString&);
- void slotCheckForExistingSymbol(const QString&);
+ void slotCheckPage(const TQString&);
+ void slotCheckForExistingSymbol(const TQString&);
void slotSourceChanged(bool);
void slotHelp(void);
@@ -39,45 +39,46 @@
* them.
*
- * @param parentId id of parent account for the investment
+ * @param tqparentId id of tqparent account for the investment
*/